import unittest

from flyers import bools


class MyTestCase(unittest.TestCase):
    def test_something(self):
        self.assertTrue(bools.is_true(1))
        self.assertTrue(bools.is_true('1'))
        self.assertTrue(bools.is_true('True'))
        self.assertTrue(bools.is_true('true'))

        self.assertFalse(bools.is_true(0))
        self.assertFalse(bools.is_true('false'))


if __name__ == '__main__':
    unittest.main()
