import unittest

from flyers import dicts


class MyTestCase(unittest.TestCase):
    def test_something(self):
        m = dicts.Multimap()
        m['a'] = 1
        m['a'] = 2
        m['a'] = 3
        self.assertListEqual(m.get('a'), [1, 2, 3])

        del m['a']


if __name__ == '__main__':
    unittest.main()
