import unittest

from flyers import files


class MyTestCase(unittest.TestCase):
    def test_something(self):
        conf = files.read_ini_file("conf.ini")
        self.assertEqual(conf['server']['host'], '127.0.0.1')  # add assertion here
        self.assertEqual(conf['server']['port'], "8080")  # add assertion here


if __name__ == '__main__':
    unittest.main()
