class Pair(object):
    def __init__(self, k, v):
        self.key = k
        self.val = v

    def __str__(self):
        return '{}->{}'.format(self.key, self.val)

    def __repr__(self):
        return self.__str__()
