from setuptools import setup, find_packages

setup(
    name='flyers',
    version='0.0.14',
    author='pushyzheng',
    author_email='1437876073@qq.com',
    url='https://github.com/pushyzheng',
    description=u'A collections of utils',
    packages=find_packages(),
    install_requires=['requests~=2.28.1', 'pymysql~=1.0.2', 'DBUtils~=3.0.2',
                      'selenium~=3.141.0', 'redis~=3.5.3', 'PyYAML~=5.4.1', 'rich~=10.16.2',
                      'schedule~=1.1.0', 'diskcache~=5.4.0']
)
